===============================
Kibitzr
===============================

.. image:: https://badges.gitter.im/kibitzr/Lobby.svg
   :alt: Join the chat at https://gitter.im/kibitzr/Lobby
   :target: https://gitter.im/kibitzr/Lobby?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge


.. image:: https://img.shields.io/pypi/v/kibitzr.svg
        :target: https://pypi.python.org/pypi/kibitzr

.. image:: https://img.shields.io/travis/kibitzr/kibitzr.svg
        :target: https://travis-ci.org/kibitzr/kibitzr?branch=master

.. image:: https://readthedocs.org/projects/kibitzr/badge/?version=latest
        :target: https://kibitzr.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://gitpitch.com/assets/badge.svg
        :target: https://gitpitch.com/kibitzr/kibitzr/master?grs=github&t=white
        :alt: GitPitch

.. image:: https://www.codefactor.io/repository/github/kibitzr/kibitzr/badge
        :target: https://www.codefactor.io/repository/github/kibitzr/kibitzr
        :alt: CodeFactor

.. image:: https://www.quantifiedcode.com/api/v1/project/cf48e075a106486fadf998d0ef99b344/badge.svg
        :target: https://www.quantifiedcode.com/app/project/cf48e075a106486fadf998d0ef99b344
        :alt: Code issues

.. image:: https://coveralls.io/repos/github/kibitzr/kibitzr/badge.svg?branch=master
        :target: https://coveralls.io/github/kibitzr/kibitzr?branch=master
        :alt: Coveralls

Kibitzr is like a secret twin brother who does routine tasks and asks for nothing in return.

* Problems? Ask in issues_, or gitter_
* Documentation: https://kibitzr.readthedocs.io.
* Free software: MIT license

.. _gitter: https://gitter.im/kibitzr/Lobby
.. _issues: https://github.com/kibitzr/kibitzr/issues/
